==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/Microsoft.Build.Framework/Microsoft.Build.Framework/BuildStatusEventArgs.cs <==
//
// BuildStatusEventArgs.cs: Provides data for the Microsoft.Build.Framework.
// IEventSource.StatusEventRaised event.
//
// Author:
//   Marek Sieradzki (marek.sieradzki@gmail.com)
// 
// (C) 2005 Marek Sieradzki
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#if NET_2_0

using System;

namespace Microsoft.Build.Framework
{
	[Serializable]
	public abstract class BuildStatusEventArgs : BuildEventArgs {
	
		protected BuildStatusEventArgs ()
		{
		}

		protected BuildStatusEventArgs (string message,
						string helpKeyword,
						string senderName)
			: base (message, helpKeyword, senderName)
		{
		}
	}
}

#endif

==> mono-4.4.2.11.tar.bz2: mono-4.4.2/mcs/class/Microsoft.Build.Framework/Microsoft.Build.Framework/BuildStatusEventArgs.cs <==
//
// BuildStatusEventArgs.cs: Provides data for the Microsoft.Build.Framework.
// IEventSource.StatusEventRaised event.
//
// Author:
//   Marek Sieradzki (marek.sieradzki@gmail.com)
// 
// (C) 2005 Marek Sieradzki
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

using System;

namespace Microsoft.Build.Framework
{
	[Serializable]
	public abstract class BuildStatusEventArgs
			: LazyFormattedBuildEventArgs {
	
		protected BuildStatusEventArgs ()
		{
		}

		protected BuildStatusEventArgs (string message,
						string helpKeyword,
						string senderName)
			: base (message, helpKeyword, senderName)
		{
		}

		protected BuildStatusEventArgs (string message,
						string helpKeyword,
						string senderName,
						DateTime eventTimestamp)
			: base (message, helpKeyword, senderName, eventTimestamp)
		{
		}

		protected BuildStatusEventArgs (string message,
						string helpKeyword,
						string senderName,
						DateTime eventTimestamp,
						params object [] messageArgs)
			: base (message, helpKeyword, senderName, eventTimestamp, messageArgs)
		{
		}
	}
}
